@@ -12,6 +12,8 @@ impl NativeRefCountedBase for SkBlender {
     type Base = SkRefCntBase;
 }
 
+impl NativeBase<SkFlattenable> for SkBlender {}
+
 impl Blender {
     /// Create a blender that implements the specified [`BlendMode`].
     pub fn mode(mode: BlendMode) -> Blender {
@@ -34,3 +36,9 @@ impl NativeFlattenable for SkBlender {
         unsafe { sb::C_SkBlender_Deserialize(data.as_ptr() as _, data.len()) }
     }
 }
+
+impl From<BlendMode> for Blender {
+    fn from(mode: BlendMode) -> Self {
+        Blender::mode(mode)
+    }
+}
