@@ -12,16 +12,11 @@ impl PathEffect {
 }
 
 pub mod path_1d_path_effect {
-    use crate::prelude::*;
-    use crate::{scalar, Path, PathEffect};
+    use crate::{prelude::*, scalar, Path, PathEffect};
     use skia_bindings::C_SkPath1DPathEffect_Make;
 
     pub use skia_bindings::SkPath1DPathEffect_Style as Style;
-
-    #[test]
-    fn style_enum_naming() {
-        let _n = Style::Translate;
-    }
+    variant_name!(Style::Translate, style_naming);
 
     pub fn new(path: &Path, advance: scalar, phase: scalar, style: Style) -> Option<PathEffect> {
         PathEffect::from_ptr(unsafe {
