@@ -1,5 +1,6 @@
+use crate::gpu;
 use crate::prelude::*;
-use skia_bindings::{self as sb, GrGLFramebufferInfo, GrGLTextureInfo};
+use skia_bindings::{self as sb, GrGLFramebufferInfo, GrGLSurfaceInfo, GrGLTextureInfo};
 
 pub use skia_bindings::GrGLFormat as Format;
 variant_name!(Format::ALPHA8, format_naming);
@@ -8,7 +9,7 @@ variant_name!(Standard::GLES, standard_naming);
 pub use skia_bindings::GrGLenum as Enum;
 pub use skia_bindings::GrGLuint as UInt;
 
-#[derive(Copy, Clone, Eq, Debug)]
+#[derive(Copy, Clone, Eq, Default, Debug)]
 #[repr(C)]
 pub struct TextureInfo {
     pub target: Enum,
@@ -24,17 +25,6 @@ impl PartialEq for TextureInfo {
     }
 }
 
-// TODO: does this make sense?
-impl Default for TextureInfo {
-    fn default() -> Self {
-        TextureInfo {
-            target: 0,
-            id: 0,
-            format: 0,
-        }
-    }
-}
-
 impl TextureInfo {
     pub fn from_target_and_id(target: Enum, id: Enum) -> Self {
         Self {
@@ -45,7 +35,7 @@ impl TextureInfo {
     }
 }
 
-#[derive(Copy, Clone, PartialEq, Eq, Debug)]
+#[derive(Copy, Clone, PartialEq, Eq, Default, Debug)]
 #[repr(C)]
 pub struct FramebufferInfo {
     pub fboid: UInt,
@@ -58,21 +48,37 @@ native_transmutable!(
     framebuffer_info_layout
 );
 
-impl Default for FramebufferInfo {
-    fn default() -> Self {
-        FramebufferInfo {
-            fboid: 0,
-            format: 0,
-        }
-    }
-}
-
 impl FramebufferInfo {
     pub fn from_fboid(fboid: UInt) -> Self {
         Self { fboid, format: 0 }
     }
 }
 
+#[derive(Copy, Clone, PartialEq, Eq, Debug)]
+#[repr(C)]
+pub struct SurfaceInfo {
+    pub sample_count: u32,
+    pub level_count: u32,
+    pub protected: gpu::Protected,
+
+    pub target: Enum,
+    pub format: Enum,
+}
+
+native_transmutable!(GrGLSurfaceInfo, SurfaceInfo, surface_info_layout);
+
+impl Default for SurfaceInfo {
+    fn default() -> Self {
+        Self {
+            sample_count: 1,
+            level_count: 0,
+            protected: gpu::Protected::No,
+            target: 0,
+            format: 0,
+        }
+    }
+}
+
 bitflags! {
     pub struct BackendState: u32 {
         const RENDER_TARGET = sb::GrGLBackendState_kRenderTarget_GrGLBackendState as _;
